@@ -1,3 +1,4 @@
+from typing import Literal
 from pydantic import BaseSettings, Field
 from emmet.api import __file__ as root_dir
 import os
@@ -9,10 +10,6 @@ class MAPISettings(BaseSettings):
     python module
     """
 
-    APP_PATH: str = Field(
-        "~/mapi.json", description="Path for the default MAPI JSON definition"
-    )
-
     DEBUG: bool = Field(False, description="Turns on debug mode for MAPI")
 
     TEST_FILES: str = Field(
@@ -24,7 +21,7 @@ class MAPISettings(BaseSettings):
 
     DB_VERSION: str = Field("2021.11.10", description="Database version")
 
-    DB_NAME_SUFFIX: str = Field(None, description="Database name suffix")
+    DB_NAME_SUFFIX: Literal["blue", "green"] = Field(None, description="Database name suffix. Either blue or green.")
 
     REQUESTS_PER_MIN: int = Field(
         100, description="Number of requests per minute to for rate limit."
