@@ -1,6 +1,6 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.dois import DOIDoc
-
+from emmet.api.core.global_header import GlobalHeaderProcessor
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 
 
@@ -12,6 +12,7 @@ def dois_resource(dois_store):
             PaginationQuery(),
             SparseFieldsQuery(DOIDoc, default_fields=["task_id", "doi"]),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["DOIs"],
         enable_default_search=False,
         disable_validation=True,
