@@ -1,6 +1,7 @@
 from maggma.api.query_operator.dynamic import NumericQuery
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.electrode import InsertionElectrodeDoc
+from emmet.api.core.global_header import GlobalHeaderProcessor
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.electrodes.query_operators import (
@@ -27,6 +28,7 @@ def insertion_electrodes_resource(insertion_electrodes_store):
                 InsertionElectrodeDoc, default_fields=["battery_id", "last_updated"],
             ),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Electrodes"],
         disable_validation=True,
     )
