@@ -3,6 +3,7 @@ from maggma.api.resource import ReadOnlyResource
 from emmet.core.eos import EOSDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from emmet.api.core.global_header import GlobalHeaderProcessor
 
 
 def eos_resource(eos_store):
@@ -15,6 +16,7 @@ def eos_resource(eos_store):
             PaginationQuery(),
             SparseFieldsQuery(EOSDoc, default_fields=["task_id"]),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["EOS"],
         disable_validation=True,
     )
