@@ -1,7 +1,7 @@
 from maggma.api.resource import ReadOnlyResource
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.routes.materials.query_operators import DeprecationQuery
-
+from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.core.provenance import ProvenanceDoc
 
 
@@ -16,6 +16,7 @@ def provenance_resource(provenance_store):
                 ProvenanceDoc, default_fields=["material_id", "last_updated"]
             ),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Provenance"],
         disable_validation=True,
     )
