@@ -8,6 +8,7 @@ from maggma.api.query_operator import (
 from maggma.api.resource import ReadOnlyResource
 
 from emmet.api.routes.substrates.query_operators import SubstrateStructureQuery
+from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.core.substrates import SubstratesDoc
 
 
@@ -25,6 +26,7 @@ def substrates_resource(substrates_store):
             PaginationQuery(),
             SparseFieldsQuery(SubstratesDoc, default_fields=["film_id", "sub_id"]),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Substrates"],
         enable_get_by_key=False,
         disable_validation=True,
